# Changelog

We are currently working on porting this changelog to the specifications in
[Keep a Changelog](https://keepachangelog.com/en/1.0.0/).
This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Version 0.2.0] - Released 2022-09-16

### Fixed
* Minor bugs

### Changed
* Remove 3.6 support
* Add 3.11 support


## [Version 0.1.0] -

### Added
* Initial version
